# 👮‍♂️ Security Policy

This document describes the security policy of this package.


## 📚 Supported Versions

The following table describes versions that are supported ✅ and unsupported ❌:


| Version | Supported |
| :------ | :-------: |
| 1.0.0   | ✅         |


## 🚓 Reporting Vulnerabilities

To report a vulnerability in this package, please contact the EDRN Informatics Center by email to: edrn-ic@jpl.nasa.gov.
